GlyphRemapper

Struct GlyphRemapper 

pub struct GlyphRemapper(/* private fields */);
A remapper that allows to assign a new ordering to a subset of glyphs.

For example, let’s say that we want to subset a font that only contains the glyphs 4, 9 and 16. In this case, the remapper could yield a remapping that assigns the following glyph IDs:

  • 0 -> 0 (The .notdef glyph will always be included)
  • 4 -> 1
  • 9 -> 2
  • 16 -> 3

This is necessary because a font needs to have a contiguous sequence of glyph IDs that start from 0, so we cannot just reuse the old ones, but we need to define a mapping.

Implementations

Source

impl GlyphRemapper

pub fn new() -> Self

Create a new instance of a glyph remapper. .notdef will always be a member of the subset.

pub fn new_from_glyphs(glyphs: &[u16]) -> Self

Create a remapper from an existing set of glyphs

pub fn new_from_glyphs_sorted(glyphs: &[u16]) -> Self

Create a remapper from an existing set of glyphs. The method will ensure that the mapping is monotonically increasing.

pub fn num_gids(&self) -> u16

Get the number of gids that have been remapped.

pub fn remap(&mut self, old: u16) -> u16

Remap a glyph ID, or return the existing mapping if the glyph ID has already been remapped before.

pub fn get(&self, old: u16) -> Option<u16>

Get the mapping of a glyph ID, if it has been remapped before.

pub fn remapped_gids(&self) -> impl Iterator<Item = u16> + '_

Return an iterator that yields the old glyphs, in ascending order that is defined by the remapping. For example, if we perform the following remappings: 3, 39, 8, 3, 10, 2

Then the iterator will yield the following items in the order below. The order also implicitly defines the glyph IDs in the new mapping:

0 (0), 3 (1), 39 (2), 8 (3), 10 (4), 2 (5)